# math_pip

This is an example Python package created by Rahul Kumar.

It provides additional math operations and utility functions.

---

## Installation

You can install the package via pip:

## how can you use in your project 

import math_pip as ms
ms.add(a,b)
ms.subtract(a,b)

```bash

pip install cal_pip